# Basic Geometry

The basic geometry commands create geometric entities that are referenced by Part objects, Instance objects, and GeometrySet objects.

## Classes

### Cell

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.Cell.Cell
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### CellArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.CellArray.CellArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Edge

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.Edge.Edge
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### EdgeArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.EdgeArray.EdgeArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Face

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.Face.Face
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### FaceArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.FaceArray.FaceArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### IgnoredEdge

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.IgnoredEdge.IgnoredEdge
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### IgnoredEdgeArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.IgnoredEdgeArray.IgnoredEdgeArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### IgnoredVertex

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.IgnoredVertex.IgnoredVertex
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### IgnoredVertexArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.IgnoredVertexArray.IgnoredVertexArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### InterestingPoint

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.InterestingPoint.InterestingPoint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ModelDot

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.ModelDot.ModelDot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ModelDotArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.ModelDotArray.ModelDotArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ReferencePoint

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.ReferencePoint.ReferencePoint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ReferencePointArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.ReferencePointArray.ReferencePointArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### ReferencePoints

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.ReferencePoints.ReferencePoints
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Transform

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.Transform.Transform
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### Vertex

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.Vertex.Vertex
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```

### VertexArray

```{eval-rst}
.. autoclass:: abaqus.BasicGeometry.VertexArray.VertexArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::
```
